// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: foldSet.h,v 1.4 1998/09/25 18:06:23 jochen Exp $




#ifndef DIALOGFOLDSET_H
#define DIALOGFOLDSET_H



#include <qdialog.h>


class Floated;
class KRotData;
class QListBox;
class QRadioButton;
class QWidget;



/**
 * Provides a selection dialog to set the folding parameter of any simulation.
 * 
 * @short Folding of simulations.
 * @author Jochen Kpper
 * @version $Id: foldSet.h,v 1.4 1998/09/25 18:06:23 jochen Exp $
 */
class DialogFoldSet : public QDialog
{
    Q_OBJECT

public:

    /**
     * Constructor.
     *
     * @param parent Passed to QDialog constructor.
     * @param name   Passed to QDialog constructor.
     */
    DialogFoldSet( KRotData *krotdata, QWidget *parent=0, const char *name=0 );


protected slots:

    /**
     * Fold the selected set by the lineshape given by the shape selection
     * and the given linewidths.
     */
    void fold();

    /**
     * Open help file of this dialog.
     */
    void help();

    /**
     * New DataSet selected. Get its lineshape parameter and
     * put them into the dialog interface.
     *
     * @param name Name of the selected DataSet.
     */
    void newSet( const char *name );

    /**
     * New Lineshape selected.
     *
     * @param name ID of the selected lineshape.
     */
    void newShape( int id );

    
signals:

    /**
     * Tell anybody that we changed things.
     * At least the DrawArea needs to be updated.
     */
    void changed();


protected:

    QListBox* list;

    QRadioButton *gaussRB, *lorentzRB, *voigtRB, *stickRB;

    Floated *gaussFWHM, *lorentzFWHM;

    KRotData *krotData;
};



#endif
